Feature Selectors Module
========================

.. automodule:: moosefs.feature_selectors.base_selector
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: moosefs.feature_selectors.f_statistic_selector
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: moosefs.feature_selectors.mutual_info_selector
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: moosefs.feature_selectors.random_forest_selector
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: moosefs.feature_selectors.svm_selector
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: moosefs.feature_selectors.xgboost_selector
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: moosefs.feature_selectors.lasso_selector
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: moosefs.feature_selectors.elastic_net_selector
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: moosefs.feature_selectors.variance_selectors
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: moosefs.feature_selectors.mrmr_selector
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: moosefs.feature_selectors.default_variance
   :members:
   :undoc-members:
   :show-inheritance:

